@@ -1,5 +1,5 @@
 import pandas as pd
-from ml.preprocessing.text_vectorizer import TextVectorizer
+from takeusecases.ml.preprocessing.text_vectorizer import TextVectorizer
 from gensim.models import KeyedVectors
 
 class Vectorizer:
@@ -47,6 +47,3 @@ class Vectorizer:
         else:
             df = self.encoder.transform(df)
         return df
-
-
-        
